==> org.eclipse.etrice.site_0.1.0.M1.201111181326.zip: org/eclipse/etrice/ui/common/preferences/PreferenceInitializer.java <==
/*******************************************************************************
 * Copyright (c) 2011 protos software gmbh (http://www.protos.de).
 * All rights reserved. This program and the accompanying materials
 * are made available under the terms of the Eclipse Public License v1.0
 * which accompanies this distribution, and is available at
 * http://www.eclipse.org/legal/epl-v10.html
 * 
 * CONTRIBUTORS:
 * 		Henrik Rentz-Reichert (initial contribution)
 * 
 *******************************************************************************/

package org.eclipse.etrice.ui.common.preferences;

import org.eclipse.core.runtime.preferences.AbstractPreferenceInitializer;
import org.eclipse.jface.preference.IPreferenceStore;

import org.eclipse.etrice.ui.common.Activator;

/**
 * Class used to initialize default preference values.
 */
public class PreferenceInitializer extends AbstractPreferenceInitializer {

	/*
	 * (non-Javadoc)
	 * 
	 * @see org.eclipse.core.runtime.preferences.AbstractPreferenceInitializer#initializeDefaultPreferences()
	 */
	public void initializeDefaultPreferences() {
		IPreferenceStore store = Activator.getDefault().getPreferenceStore();
		store.setDefault(PreferenceConstants.USE_GRID, true);
		store.setDefault(PreferenceConstants.SNAP_TO_GRID, false);
		store.setDefault(PreferenceConstants.HOR_GRID_UNIT, 10);
		store.setDefault(PreferenceConstants.VER_GRID_UNIT, 10);
		store.setDefault(PreferenceConstants.DATA_DRIVEN_FSM, false);
		store.setDefault(PreferenceConstants.CONFIRM_DELETE, true);
	}

}

==> org.eclipse.etrice.site_0.2.0.M2.201205211000.zip: org/eclipse/etrice/ui/common/preferences/PreferenceInitializer.java <==
/*******************************************************************************
 * Copyright (c) 2011 protos software gmbh (http://www.protos.de).
 * All rights reserved. This program and the accompanying materials
 * are made available under the terms of the Eclipse Public License v1.0
 * which accompanies this distribution, and is available at
 * http://www.eclipse.org/legal/epl-v10.html
 * 
 * CONTRIBUTORS:
 * 		Henrik Rentz-Reichert (initial contribution)
 * 
 *******************************************************************************/

package org.eclipse.etrice.ui.common.preferences;

import org.eclipse.core.runtime.preferences.AbstractPreferenceInitializer;
import org.eclipse.jface.preference.IPreferenceStore;

import org.eclipse.etrice.ui.common.Activator;

/**
 * Class used to initialize default preference values.
 */
public class PreferenceInitializer extends AbstractPreferenceInitializer {

	/*
	 * (non-Javadoc)
	 * 
	 * @see org.eclipse.core.runtime.preferences.AbstractPreferenceInitializer#initializeDefaultPreferences()
	 */
	public void initializeDefaultPreferences() {
		IPreferenceStore store = Activator.getDefault().getPreferenceStore();
		store.setDefault(PreferenceConstants.USE_GRID, true);
		store.setDefault(PreferenceConstants.SNAP_TO_GRID, false);
		store.setDefault(PreferenceConstants.HOR_GRID_UNIT, 10);
		store.setDefault(PreferenceConstants.VER_GRID_UNIT, 10);
		store.setDefault(PreferenceConstants.CONFIRM_DELETE, true);
		store.setDefault(PreferenceConstants.SAVE_DIAG_ON_FOCUS_LOST, false);
	}

}
